@@ -53,6 +53,7 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
         super(XpcsViewer, self).__init__()
         self.setupUi(self)
         self.tab_id = 0
+        self.home_dir = home_dir
 
         self.tabWidget.setCurrentIndex(self.tab_id)
         self.tab_dict = {
@@ -119,14 +120,18 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
         self.avg_job_table.clicked.connect(self.update_avg_info)
         self.hdf_key_filter.textChanged.connect(self.show_hdf_info)
         self.load_default_setting()
+
+        # disable browse function; it freezes on linux workstation;
+        # self.pushButton.setEnabled(False)
+
         self.show()
     
     def load_default_setting(self):
-        home_dir = os.path.join(os.path.expanduser('~'), '.xpcs_viewer')
-        if not os.path.isdir(home_dir):
-            os.mkdir(home_dir)
+        # home_dir = os.path.join(os.path.expanduser('~'), '.xpcs_viewer')
+        if not os.path.isdir(self.home_dir):
+            os.mkdir(self.home_dir)
 
-        key_fname = os.path.join(home_dir, 'default_setting.json')
+        key_fname = os.path.join(self.home_dir, 'default_setting.json')
         # copy the default values
         if not os.path.isfile(key_fname):
             from .default_setting import setting
@@ -165,6 +170,8 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
             self.plot_saxs_1D()
         elif tab_name == 'intensity_t':
             self.plot_intt()
+        elif tab_name == 'g2':
+            self.plot_g2()
 
     def init_tab(self):
         if self.data_state < 2:
@@ -199,7 +206,7 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
             self.update_average_box()
         elif tab_name == 'g2':
             self.set_g2_range()
-            # self.plot_g2(10)
+            self.plot_g2(10)
 
         self.plot_state[new_tab_id] = 1
 
@@ -570,7 +577,7 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
         if not self.check_status() or self.vk.type != 'Multitau':
             return
 
-        flag, tel, _, _, _ = self.vk.get_g2_data(max_points)
+        flag, tel, _, _, _ = self.vk.get_g2_data(max_points, rows=None)
         if not flag:
             self.statusbar.showMessage('g2 data is not consistent. abort')
         t_min = np.min(tel)
@@ -598,6 +605,7 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
             'q_range': (p[0], p[1]),
             't_range': (p[2], p[3]),
             'y_range': (p[4], p[5]),
+            'rows': self.get_selected_rows(),
         }
 
         bounds = self.check_number()
